package de.cweiske.jOnlineControl;

import com.martiansoftware.jsap.*;
import de.cweiske.jOnlineControl.connectors.Connector;
import de.cweiske.jOnlineControl.connectors.DriverList;

/**
 * CommandLine interface for jOnlineControl
 *
 * java -jar jOnlineControl.jar --router=192.168.3.99 status
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class CommandLine
{
    String routerIp = "192.168.2.1";
    String driver = "Telekom";
    String action = "status";

    public static void main(String[] args) throws JSAPException
    {
        new CommandLine(args);
    }//public static void main(String[] args) throws JSAPException



    public CommandLine(String[] args) throws JSAPException
    {
        handleArgs(args);

        Connector con = DriverList.createNewInstance(this.driver);

        if (!con.setAddress(this.routerIp)) {
            System.err.println("The hostname \"" + this.routerIp + "\" cannot be resolved.");
        }

        if (this.action.equals("status")) {
            System.out.println("Status of " + this.routerIp);
            Status status = con.getStatus();
            if (status == null) {
                System.err.println("Error getting status - maybe the router cannot be reached.\nTry to set the router ip with --router=1.2.3.4");
            } else {
                System.out.println(status);
            }

        } else if (this.action.equals("connect")) {
            if (con.connect()) {
                System.out.println("Router tries to connect.");
            } else {
                System.err.println("Error trying to connect.");
            }

        } else if (this.action.equals("disconnect")) {
            if (con.disconnect()) {
                System.out.println("Router tries to disconnect.");
            } else {
                System.err.println("Error trying to disconnect.");
            }

        } else {
            System.err.println("Unknown action \"" + action + "\"");
        }
    }//public CommandLine(String[] args)



    protected void handleArgs(String[] args) throws JSAPException
    {
        SimpleJSAP jsap = new SimpleJSAP(
            "jOnlineControl",
            "Shows status information of a router, connects and disconnects.",
            new Parameter[] {
                new FlaggedOption("router", JSAP.STRING_PARSER, this.routerIp, false, 'r', "router", "Router IP"),
                new FlaggedOption("driver", JSAP.STRING_PARSER, this.driver, false, 'd', "driver", "Driver to use (currently only Telekom)"),
                new UnflaggedOption("action", JSAP.STRING_PARSER, this.action, false, false, "can be status/connect/disconnect")
            }
        );

        JSAPResult config = jsap.parse(args);

        if (!config.success() || config.getBoolean("help")) {
            System.err.println();
            System.err.println("Usage: java -jar jOnlineControl.jar ");
            System.err.println("                "
                                + jsap.getUsage());
            System.err.println();
            System.exit(1);
        }

        this.routerIp = config.getString("router");
        this.driver   = config.getString("driver");
        this.action   = config.getString("action");
    }//protected void handleArgs(String[] args) throws JSAPException

}//public class CommandLine
