package de.cweiske.jOnlineControl;

import de.cweiske.jOnlineControl.frontend.SimpleWindow;
import de.cweiske.jOnlineControl.frontend.TrayIcon;
import de.cweiske.jOnlineControl.connectors.Connector;
import de.cweiske.jOnlineControl.connectors.DriverList;

import javax.swing.*;
import java.util.ResourceBundle;
import java.awt.*;
import java.io.IOException;

import com.martiansoftware.jsap.*;

/**
 * Frontend fr jOnlineControl
 *
 * Chooses the best available frontend.
 */
public class Frontend
{
    public static ResourceBundle resbundle = ResourceBundle.getBundle("de.cweiske.jOnlineControl.Frontend");
    public static final String version = "0.6";
    public static final String versionName = "Brombeere";

    /**
     * Checks if the tray class is available, and starts the frontend class
     *
     * @param args Program arguments
     */
    public static void main(String[] args) throws JSAPException
    {
        boolean trayAvailable = true;
        try {
            Class.forName("org.jdesktop.jdic.tray.TrayIcon");
        } catch (ClassNotFoundException e) {
            //No tray
            trayAvailable = false;
        }

        SimpleJSAP jsap = new SimpleJSAP(
            "jOnlineControl",
            "Shows status information of a router, connects and disconnects.",
            new Parameter[] {
                new FlaggedOption("router", JSAP.STRING_PARSER, null, false, 'r', "router", "Router IP"),
                new FlaggedOption("driver", JSAP.STRING_PARSER, null, false, 'd', "driver", "Driver to use (currently only Telekom)"),
                new Switch("notray", 't', "notray", "Do not use tray icon")
            }
        );

        JSAPResult config = jsap.parse(args);

        if (!config.success() || config.getBoolean("help")) {
            System.err.println();
            System.err.println("Usage: java -jar jOnlineControl.jar ");
            System.err.println("                "
                                + jsap.getUsage());
            System.err.println();
            System.exit(1);
        }


        String routerIp = config.getString("router");
        String driver   = config.getString("driver");
        boolean notray  = config.getBoolean("notray");

        if (driver == null) {
            driver = Settings.singleton().getDriver();
        }


        Connector connector = DriverList.createNewInstance(driver);

        if (routerIp != null) {
            Settings.singleton().setIp(routerIp);
        }

        connector.setAddress(Settings.singleton().getIp());

        if (!notray && trayAvailable) {
            new TrayIcon(connector);
        } else {
            new SimpleWindow(connector);
        }
    }//public static void main(String[] args) throws JSAPException



    /**
     * runs a given script
     */
    public static void runScript(String strCommand, Component cParent)
    {
        if (strCommand == null || strCommand.equals("")) {
            return;
        }

        try {
            Runtime.getRuntime().exec( strCommand);
        } catch( IOException e ) {
            if (cParent != null) {
                JOptionPane.showMessageDialog( cParent, e.getMessage() + "\r\n" + e.getClass());
            } else {
                System.out.println( "Error running script: " + strCommand );
                System.out.println( e.getMessage());
                System.out.println( e.getCause());
            }
        }
    }//public void runScript(String strCommand, boolean bShowErrorDialog)
}
