package de.cweiske.jOnlineControl;

import de.cweiske.jOnlineControl.connectors.DriverList;

import java.util.prefs.Preferences;
import java.util.regex.Pattern;

/**
 * Default settings
 */
public class Settings
{
    protected static Settings settings;
    protected static final String prefPath = "/de/cweiske/jOnlineControl";
    Preferences prefs;

    protected static final String nameDriver            = "driver";
    protected static final String nameIp                = "router";
    protected static final String nameScriptConnect     = "connect";
    protected static final String nameScriptDisconnect  = "disconnect";

    protected String driver;
    protected String ip;
    protected String scriptConnect;
    protected String scriptDisconnect;


    private Settings()
    {
        Preferences root        = java.util.prefs.Preferences.userRoot();
        prefs                   = root.node(prefPath);
        this.loadSettings();
    }

    public static Settings singleton()
    {
        if (Settings.settings == null) {
            Settings.settings = new Settings();
        }
        return Settings.settings;
    }



    public void loadSettings()
    {
        this.driver             = prefs.get(nameDriver, "Telekom");
        this.ip                 = prefs.get(nameIp, "192.168.2.1");
        this.scriptConnect      = prefs.get(nameScriptConnect, "");
        this.scriptDisconnect   = prefs.get(nameScriptDisconnect, "");
    }//public void loadSettings()



    public void saveSettings()
    {
        prefs.put(nameDriver            , this.driver);
        prefs.put(nameIp                , this.ip);
        prefs.put(nameScriptConnect     , scriptConnect);
        prefs.put(nameScriptDisconnect  , scriptDisconnect);
    }//public void saveSettings()



    public String getScriptDisconnect()
    {
        return scriptDisconnect;
    }



    public boolean setScriptDisconnect(String scriptDisconnect)
    {
        this.scriptDisconnect = scriptDisconnect;
        return true;
    }



    public String getScriptConnect()
    {
        return scriptConnect;
    }



    public boolean setScriptConnect(String scriptConnect)
    {
        this.scriptConnect = scriptConnect;
        return true;
    }



    public String getIp()
    {
        return ip;
    }



    public boolean setIp(String ip)
    {
        String strPatternNumber = "(0?0?\\d|[01]?\\d\\d|2[0-4]\\d|25[0-5])";
        Pattern ptIp	= Pattern.compile( "([a-zA-Z\\.]+)|(" + strPatternNumber + "\\." + strPatternNumber + "\\." + strPatternNumber + "\\." + strPatternNumber + ")");

        boolean bIpOk = ptIp.matcher( ip).matches();

        if (!bIpOk) {
            return false;
        }

        this.ip = ip;
        return true;
    }//public boolean setIp(String ip)



    public String getDriver()
    {
        return driver;
    }



    public boolean setDriver(String driver)
    {
        boolean found = false;
        for (int i = 0; i < DriverList.drivers.length; i++) {
            String s = DriverList.drivers[i];
            if (s.equals(driver)) {
                found = true;
                break;
            }
        }

        if (found) {
            this.driver = driver;
            return true;
        } else {
            return false;
        }
    }//public boolean setDriver(String driver)


}//public class Settings