package de.cweiske.jOnlineControl;

import de.cweiske.jOnlineControl.frontend.Updateable;
import de.cweiske.jOnlineControl.frontend.helper.SwingHelper;
import de.cweiske.jOnlineControl.connectors.DriverList;
import de.cweiske.jOnlineControl.connectors.Connector;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;



/**
 * dialog which collects settings for jOnlineControl
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class SettingsDialog extends JFrame implements ActionListener
{

    public static void main(String[] args)
    {
        new SettingsDialog(null);
    }//public static void main(String[] args)



    protected JComboBox cmbDriver;
    protected JTextField txtIp;
    protected JTextField txtConnect;
    protected JTextField txtDisconnect;

    protected JButton btnCancel;
    protected JButton btnSave;
    protected JButton btnApply;

    protected JButton btnTestConnect;
    protected JButton btnTestDisconnect;

    protected Updateable updateable;
    protected String currentDriver = "Ping";



    public SettingsDialog(Updateable updateable)
    {
        super(Frontend.resbundle.getString("settings.title"));

        this.updateable = updateable;

        this.initGui();
        this.loadSettings();

        this.show();
    }//public SettingsDialog(ResourceBundle resbundle)



    /**
     * initialized the buttons and boxes
     */
    private void initGui()
    {
        Container cp = this.getContentPane();
        cp.setLayout( new BorderLayout());

        GridBagLayout gl = new GridBagLayout();
        JPanel pnl = new JPanel(gl);

        GridBagConstraints gc = new GridBagConstraints();
        cp.add( pnl, BorderLayout.NORTH);

        JLabel lblDriver        = new JLabel(Frontend.resbundle.getString("settings.lbl.driver"));
        JLabel lblIp			= new JLabel(Frontend.resbundle.getString("settings.lbl.ip"));
        JLabel lblConnect		= new JLabel(Frontend.resbundle.getString("settings.lbl.connect"));
        JLabel lblDisconnect	= new JLabel(Frontend.resbundle.getString("settings.lbl.disconnect"));

        this.btnTestConnect		= new JButton(Frontend.resbundle.getString("settings.button.connect"));
        this.btnTestDisconnect	= new JButton(Frontend.resbundle.getString("settings.button.disconnect"));

        this.txtConnect			= new JTextField();
        this.txtDisconnect		= new JTextField();
        this.txtIp				= new JTextField();
        this.cmbDriver          = new JComboBox(DriverList.drivers);

        if (this.updateable != null && this.updateable.getConnector() != null) {
            this.currentDriver = this.updateable.getConnector().getClass().getName().substring(
                    this.updateable.getConnector().getClass().getName().lastIndexOf('.') + 1
            );
        }

        this.cmbDriver.setSelectedItem(this.currentDriver);
        this.cmbDriver.addActionListener(this);


        gc.fill = GridBagConstraints.HORIZONTAL;
        SwingHelper.addComponentToPanel(pnl, gl, lblDriver          , gc, 0, 0);
        SwingHelper.addComponentToPanel(pnl, gl, lblIp              , gc, 0, 1);
        SwingHelper.addComponentToPanel(pnl, gl, lblConnect         , gc, 0, 2);
        SwingHelper.addComponentToPanel(pnl, gl, lblDisconnect      , gc, 0, 3);
        gc.weightx = 100;
        SwingHelper.addComponentToPanel(pnl, gl, cmbDriver          , gc, 1, 0);
        SwingHelper.addComponentToPanel(pnl, gl, txtIp              , gc, 1, 1);
        SwingHelper.addComponentToPanel(pnl, gl, txtConnect         , gc, 1, 2);
        SwingHelper.addComponentToPanel(pnl, gl, txtDisconnect      , gc, 1, 3);
        gc.weightx = 0;
        SwingHelper.addComponentToPanel(pnl, gl, btnTestConnect     , gc, 2, 2);
        SwingHelper.addComponentToPanel(pnl, gl, btnTestDisconnect  , gc, 2, 3);


        //buttons
        this.btnCancel		= new JButton(Frontend.resbundle.getString("settings.button.cancel"));
        this.btnSave		= new JButton(Frontend.resbundle.getString("settings.button.save"));
        this.btnApply		= new JButton(Frontend.resbundle.getString("settings.button.apply"));

        JPanel pnlButtons = new JPanel(new BorderLayout());
        cp.add( pnlButtons, BorderLayout.SOUTH);

        pnlButtons.add( this.btnCancel, BorderLayout.WEST);

        JPanel pnlConnection = new JPanel(new FlowLayout(FlowLayout.LEFT, 2, 0));
        pnlButtons.add( pnlConnection, BorderLayout.EAST);

        pnlConnection.add( this.btnApply);
        pnlConnection.add( this.btnSave);

        this.btnCancel	.addActionListener( this);
        this.btnSave	.addActionListener( this);
        this.btnApply	.addActionListener( this);

        this.btnTestConnect		.addActionListener( this);
        this.btnTestDisconnect	.addActionListener( this);

        this.setDefaultCloseOperation( JFrame.DISPOSE_ON_CLOSE);
        this.setSize( 400, 150);
    }//private void initGui()



    public void actionPerformed( ActionEvent event )
    {
        if (event.getSource() == this.btnCancel) {
            this.dispose();
        } else if (event.getSource() == this.btnSave) {
            if (this.saveSettings()) {
                this.dispose();
            }
        } else if (event.getSource() == this.btnApply) {
            this.saveSettings();
        } else if (event.getSource() == this.btnTestConnect) {
            Frontend.runScript( this.txtConnect.getText(), this);
        } else if (event.getSource() == this.btnTestDisconnect) {
            Frontend.runScript( this.txtDisconnect.getText(), this);
        } else if (event.getSource() == this.cmbDriver) {
            //create a driver instance to get the default ip
            Connector connector = DriverList.createNewInstance(this.cmbDriver.getSelectedItem().toString());
            this.txtIp.setText(connector.getDefaultIp());
        }
    }//public void actionPerformed( ActionEvent event )



    /**
     * loads the settings from the preferences and displays them in the widgets
     */
    private void loadSettings()
    {
        Settings settings = Settings.singleton();
        this.txtIp			.setText(settings.getIp());
        this.txtConnect		.setText(settings.getScriptConnect());
        this.txtDisconnect	.setText(settings.getScriptDisconnect());
    }//private void loadSettings()



    /**
     * saves the settings from the preferences
     * checks before saving; doesn't save if check isn't successful
     */
    private boolean saveSettings()
    {
        Settings settings = Settings.singleton();
        if (!settings.setIp(this.txtIp.getText())) {
            this.txtIp.requestFocus();
            JOptionPane.showMessageDialog(
                    this,
                    Frontend.resbundle.getString("settings.error.invalidip"),
                    Frontend.resbundle.getString("settings.title"),
                    JOptionPane.ERROR_MESSAGE
            );
            return false;
        }

        String newDriver = (String)this.cmbDriver.getSelectedItem();
        if (!settings.setDriver(newDriver)) {
            this.cmbDriver.requestFocus();
            JOptionPane.showMessageDialog(
                    this,
                    Frontend.resbundle.getString("settings.error.invaliddriver"),
                    Frontend.resbundle.getString("settings.title")
                            .replaceAll("\\{0\\}", newDriver),
                    JOptionPane.ERROR_MESSAGE
            );
            return false;
        }

        settings.setScriptConnect   (this.txtConnect.getText());
        settings.setScriptDisconnect(this.txtDisconnect.getText());


        settings.saveSettings();


        if (!newDriver.equals(this.currentDriver)) {
            //we have a new driver - create an instance!
            this.updateable.setConnector(DriverList.createNewInstance(newDriver));
            this.currentDriver = newDriver;
        }


        //reload the settings in the tray menu
        if (this.updateable != null) {
            this.updateable.reloadSettings();
        }

        return true;
    }//private boolean saveSettings()


}//public class SettingsDialog extends JFrame
