package de.cweiske.jOnlineControl;

import de.cweiske.jOnlineControl.connectors.Connector;
import de.cweiske.jOnlineControl.frontend.Updateable;

import java.util.TimerTask;
import java.util.Timer;

/**
 * Checks the current status in intervals of a second or so
 * Notifies the frontend if something changed.
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class StatusControl extends TimerTask
{
    Updateable updateable;

    /**
     * If the status was NULL previously
     */
    boolean bWasNull = false;

    /**
     * If the router was connected previously
     */
    boolean bWasConnected = false;



    public StatusControl(Updateable updateable)
    {
        this.updateable = updateable;
    }//public StatusControl(Updateable updateable)



    public void startTimer()
    {
        Timer timer = new Timer();
        timer.scheduleAtFixedRate(this, 0, 1000);
    }//public void startTimer()



    public void resetStatus()
    {
        this.bWasNull = true;
        this.bWasConnected = false;
    }//public void resetStatus()



    /**
     * Timer says timeout
     */
    public void run()
    {
        this.updateInformation();
    }//public void run()



    protected void updateInformation()
    {
        //load it now, because it might have been changed
        // in the updateable (driver change)
        Connector connector = this.updateable.getConnector();

        if (connector == null) {
            return;
        }
        Status status = connector.getStatus();

        boolean bChanged =
                (status == null) != bWasNull
                || (status != null && status.isConnected() != bWasConnected);

        this.bWasNull       = status == null;
        this.bWasConnected  = status != null && status.isConnected();

        if (bChanged) {
            if (status != null && status.isConnected()) {
                Frontend.runScript(Settings.singleton().getScriptConnect(), null);
            } else {
                Frontend.runScript(Settings.singleton().getScriptDisconnect(), null);
            }
            this.updateable.updateStatus(status);
        }
    }//protected void updateInformation()

}//public class StatusControl extends TimerTask