package de.cweiske.jOnlineControl;

import de.cweiske.jOnlineControl.connectors.Telekom;
import de.cweiske.jOnlineControl.connectors.Connector;
import de.cweiske.jOnlineControl.frontend.Updateable;
import de.cweiske.jOnlineControl.frontend.helper.SwingHelper;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.util.Timer;


/**
 * jOnlineControl status window
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class StatusFrame extends JFrame implements ActionListener
{
    JLabel     lblConnected;
    JTextField txtIp;
    JTextField txtSubnetmask;
    JTextField txtGateway;
    JTextField txtPrimaryDns;
    JTextField txtSecondaryDns;

    JButton btnConnect;
    JButton btnDisconnect;
    JButton btnClose;

    boolean bStandalone = false;

    String strConnected;
    String strDisconnected;
    protected Updateable updateable;



    public static void main(String[] args)
    {

        if (args.length == 0) {
            JOptionPane.showMessageDialog(
                    null,
                    Frontend.resbundle.getString("status.passip"),
                    Frontend.resbundle.getString("program.title"),
                    JOptionPane.ERROR_MESSAGE
            );
            System.exit(1);
        }

        String strAddress = args[0];
        Connector con = new Telekom();
        con.setAddress( strAddress);
        StatusFrame frm = new StatusFrame(null, true);
        frm.display();
    }//public static void main(String[] args)



    public StatusFrame(Updateable updateable, boolean bStandalone)
    {
        super(Frontend.resbundle.getString("status.title"));
        this.bStandalone = bStandalone;
        this.initGui();
        this.updateable = updateable;

        if (this.bStandalone) {
            this.setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE);
        } else {
            this.setDefaultCloseOperation( JFrame.HIDE_ON_CLOSE);
        }

        Status status;
        if (this.updateable != null) {
            status = this.updateable.getConnector().getStatus();
            this.updateStatus(status);
        }

        if (this.bStandalone) {
            Timer timer = new Timer();
            timer.scheduleAtFixedRate(new StatusFrameTimerTask(this), 0, 1000);
        }
    }//public StatusFrame(Connector con, boolean bStandalone)



    public void display()
    {
        this.show();
    }



    protected void initGui()
    {
        this.setSize( 300, 240);
        Container cp = this.getContentPane();
        cp.setLayout( new BorderLayout());

        GridBagLayout gl = new GridBagLayout();
        JPanel pnlStatus = new JPanel(gl);
        cp.add( pnlStatus, BorderLayout.NORTH);

        GridBagConstraints gc = new GridBagConstraints();
        gc.fill = GridBagConstraints.HORIZONTAL;

        this.lblConnected	= new JLabel();
        this.txtIp			= new JTextField();
        this.txtSubnetmask	= new JTextField();
        this.txtGateway		= new JTextField();
        this.txtPrimaryDns	= new JTextField();
        this.txtSecondaryDns= new JTextField();

        this.strConnected		= Frontend.resbundle.getString("status.connected");
        this.strDisconnected	= Frontend.resbundle.getString("status.disconnected");


        gc.weightx = 0;
        SwingHelper.addComponentToPanel(pnlStatus, gl, new JLabel(Frontend.resbundle.getString("status.connection")), gc, 0, 0);
        SwingHelper.addComponentToPanel(pnlStatus, gl, new JLabel(Frontend.resbundle.getString("status.ip"))        , gc, 0, 1);
        SwingHelper.addComponentToPanel(pnlStatus, gl, new JLabel(Frontend.resbundle.getString("status.subnetmask")), gc, 0, 2);
        SwingHelper.addComponentToPanel(pnlStatus, gl, new JLabel(Frontend.resbundle.getString("status.gateway"))   , gc, 0, 3);
        SwingHelper.addComponentToPanel(pnlStatus, gl, new JLabel(Frontend.resbundle.getString("status.primarydns")), gc, 0, 4);
        SwingHelper.addComponentToPanel(pnlStatus, gl, new JLabel(Frontend.resbundle.getString("status.secondarydns")), gc, 0, 5);

        gc.weightx = 100;
        SwingHelper.addComponentToPanel(pnlStatus, gl, this.lblConnected    , gc, 1, 0);
        SwingHelper.addComponentToPanel(pnlStatus, gl, this.txtIp           , gc, 1, 1);
        SwingHelper.addComponentToPanel(pnlStatus, gl, this.txtSubnetmask   , gc, 1, 2);
        SwingHelper.addComponentToPanel(pnlStatus, gl, this.txtGateway      , gc, 1, 3);
        SwingHelper.addComponentToPanel(pnlStatus, gl, this.txtPrimaryDns   , gc, 1, 4);
        SwingHelper.addComponentToPanel(pnlStatus, gl, this.txtSecondaryDns , gc, 1, 5);

        pnlStatus.setBorder( BorderFactory.createTitledBorder(Frontend.resbundle.getString("status.bordertitle")));

        //Buttons
        this.btnConnect		= new JButton(Frontend.resbundle.getString("status.button.connect"));
        this.btnDisconnect	= new JButton(Frontend.resbundle.getString("status.button.disconnect"));
        this.btnClose		= new JButton(Frontend.resbundle.getString("status.button.close"));

        JPanel pnlButtons = new JPanel(new BorderLayout());
        cp.add( pnlButtons, BorderLayout.SOUTH);

        pnlButtons.add( this.btnClose, BorderLayout.EAST);

        JPanel pnlConnection = new JPanel(new FlowLayout(FlowLayout.LEFT, 2, 0));
        pnlButtons.add( pnlConnection, BorderLayout.WEST);

        pnlConnection.add( this.btnConnect);
        pnlConnection.add( this.btnDisconnect);

        this.btnClose		.addActionListener( this);
        this.btnConnect		.addActionListener( this);
        this.btnDisconnect	.addActionListener( this);
    }//protected void initGui()



    /**
     * updates the status information
     */
    public void updateStatus(Status status)
    {
        if (status == null) {
            //status is null; we've got an error...
            this.btnConnect			.setEnabled( false);
            this.btnDisconnect		.setEnabled( false);
            this.lblConnected		.setText( Frontend.resbundle.getString("error.checkip"));
            this.txtIp				.setText( "");
            if (this.updateable.getConnector() != null) {
                this.txtIp			.setText(Status.ip2string(this.updateable.getConnector().getAddress()));
            }
            this.txtSubnetmask		.setText( "");
            this.txtGateway			.setText( "");
            this.txtPrimaryDns		.setText( "");
            this.txtSecondaryDns	.setText( "");
            return;
        }

        this.lblConnected		.setText(status.isConnected() ? this.strConnected : this.strDisconnected);
        this.txtIp				.setText(Status.ip2string(status.getWanIp()));
        this.txtSubnetmask		.setText(Status.ip2string(status.getWanSubnetMask()));
        this.txtGateway			.setText(Status.ip2string(status.getWanGateway()));
        this.txtPrimaryDns		.setText(Status.ip2string(status.getPrimaryDns()));
        this.txtSecondaryDns	.setText(Status.ip2string(status.getSecondaryDns()));

        this.btnConnect			.setEnabled( !status.isConnected());
        this.btnDisconnect		.setEnabled( status.isConnected());
    }//public void updateStatus(Status status)



    public void updateStatus()
    {
        if (this.updateable != null) {
            this.updateStatus(this.updateable.getConnector().getStatus());
        }
    }//public void updateStatus()



    public void actionPerformed( ActionEvent event )
    {
        if (event.getSource() == this.btnClose) {
            if (this.getDefaultCloseOperation() == JFrame.EXIT_ON_CLOSE) {
                System.exit( 0);
            } else {
                this.hide();
            }
        } else if (event.getSource() == this.btnConnect) {
            //connect
            this.updateable.connect();
        } else {
            //disconnect
            this.updateable.disconnect();
        }
    }//public void actionPerformed( ActionEvent event )

}//public class StatusFrame extends JFrame
