package de.cweiske.jOnlineControl.connectors;

import de.cweiske.jOnlineControl.Status;

import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * Pings a host to see if it's online.
 * Java does not provide a way to directly send ICMP requests
 * so we need to use a command line program.
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class Ping extends AddressConnector implements Connector
{
    public String getDefaultIp()
    {
        return "127.0.0.1";
    }



    public boolean connect()
    {
        return true;
    }



    public boolean disconnect()
    {
        return true;
    }



    public Status getStatus()
    {
        Status status = new Status();

        String command;
        if (System.getProperty("os.name").toUpperCase().indexOf("WINDOWS") != -1) {
            //windows' ping wants a "n"
            command = "ping -n 1";
        } else {
            //all other a "c"
            command = "ping -c 1";
        }

        try {
            Process p;
            p = Runtime.getRuntime().exec(command + " " + Status.ip2string(this.host));
            int returnCode = p.waitFor();
            status.setConnected(returnCode == 0);
        } catch (IOException e) {
            status.setConnected(false);
        } catch (InterruptedException e) {
            status.setConnected(false);
        }

        return status;
    }//public Status getStatus()

}//public class Ping extends AddressConnector implements Connector