package de.cweiske.jOnlineControl.connectors;

import de.cweiske.jOnlineControl.Status;

import java.net.*;
import java.io.*;
import java.util.regex.Pattern;
import java.util.regex.Matcher;



/**
 * Router interface for Telekom routers like
 * Sinus 1054 DSL
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class Telekom extends AddressConnector implements Connector
{
    protected static final String strPageStatus     = "/hcti_status_ocontrol.htm";
    protected static final String strPageConnect    = "/cgi-bin/connect.exe";
    protected static final String strPageDisconnect = "/cgi-bin/disconnect.exe";

    protected static int nTimeout        = 100;
    protected static int nConnectTimeout = 500;

    protected static final String defaultIp = "192.168.2.1";


    public boolean connect()
    {
        Socket sock;
        OutputStream out;
        try {
            sock = new Socket(host, 80);
            sock.setSoTimeout( Telekom.nTimeout);
            out = sock.getOutputStream();
        } catch( IOException e ) {
            e.printStackTrace();
            return false;
        }

        String strRequest = "GET " + Telekom.strPageConnect + " HTTP/1.1\r\n"
                            + "Host: " + this.host.toString() + "\r\n"
                            + "Connection: Close\r\n\r\n";

        try {
            out.write( strRequest.getBytes());
        } catch( IOException e ) {
            e.printStackTrace();
            return false;
        }

        return true;
    }//public boolean connect()



    public boolean disconnect()
    {
        Socket sock;
        OutputStream out;
        try {
            sock = new Socket(host, 80);
            sock.setSoTimeout( Telekom.nConnectTimeout);
            out = sock.getOutputStream();
        } catch( IOException e ) {
            e.printStackTrace();
            return false;
        }

        String strRequest = "GET " + Telekom.strPageDisconnect + " HTTP/1.1\r\n"
                            + "Host: " + this.host.toString() + "\r\n"
                            + "Connection: Close\r\n\r\n";

        try {
            out.write( strRequest.getBytes());
        } catch( IOException e ) {
            e.printStackTrace();
            return false;
        }

        return true;
    }//public boolean disconnect()



    public Status getStatus( )
    {
        if (host == null) {
            return null;
        }

        Socket sock;
        InputStream in;
        OutputStream out;
        try {
    //			sock = new Socket(host, 80);
            sock = new Socket();
            sock.setSoTimeout( Telekom.nTimeout);
            sock.connect( new InetSocketAddress(host, 80), Telekom.nTimeout);

            in = sock.getInputStream();
            out = sock.getOutputStream();
        } catch( NoRouteToHostException e) {
    //			System.out.println( "Can't connect to router. Check IP.");
            return null;
        } catch( SocketException e) {
            //interface isn't set up
            return null;
        } catch( SocketTimeoutException e) {
            //network cable not attached
            return null;
        } catch( IOException e ) {
            e.printStackTrace();
            return null;
        }

        String strRequest = "GET " + Telekom.strPageStatus + " HTTP/1.1\r\n"
                            + "Host: " + this.host.toString() + "\r\n"
                            + "Connection: Close\r\n\r\n";


        try {
            out.write( strRequest.getBytes());
        } catch( IOException e ) {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
            return null;
        }
        BufferedReader stdIn = new BufferedReader(new InputStreamReader(in));

        Status status = new Status();

        //read the response
        try {
            String strLine;
            Pattern ptConnected		= Pattern.compile( ".*bWanConnected=(0|1).*");
            Pattern ptIp			= Pattern.compile( ".*wan_ip=\"([0-9\\.]+)\".*");
            Pattern ptSubnetmask	= Pattern.compile( ".*wan_subnet_mask=\"([0-9\\.]+)\".*");
            Pattern ptGateway		= Pattern.compile( ".*wan_gateway=\"([0-9\\.]+)\".*");
            Pattern ptPrimaryDns	= Pattern.compile( ".*primary_dns=\"([0-9\\.]+)\".*");
            Pattern ptSecondaryDns	= Pattern.compile( ".*secondary_dns=\"([0-9\\.]+)\".*");

            Matcher m;

            while ((strLine = stdIn.readLine()) != null) {
                m = ptConnected.matcher( strLine);
                if (m.matches()) {
                    status.setConnected(m.group(1).equals( "1"));
                } else if ((m = ptIp.matcher( strLine)) != null && m.matches()) {
                    status.setWanIp(InetAddress.getByName( m.group( 1)));
                } else if ((m = ptSubnetmask.matcher( strLine)) != null && m.matches()) {
                    status.setWanSubnetMask(InetAddress.getByName( m.group( 1)));
                } else if ((m = ptGateway.matcher( strLine)) != null && m.matches()) {
                    status.setWanGateway(InetAddress.getByName( m.group( 1)));
                } else if ((m = ptPrimaryDns.matcher( strLine)) != null && m.matches()) {
                    status.setPrimaryDns(InetAddress.getByName( m.group( 1)));
                } else if ((m = ptSecondaryDns.matcher( strLine)) != null && m.matches()) {
                    status.setSecondaryDns(InetAddress.getByName( m.group( 1)));
                }
            }
            sock.close();

        } catch( IOException e) {
    //			e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
            return null;
        }


        return status;
    }//public Status getStatus()



    public String getDefaultIp()
    {
        return defaultIp;
    }

}//public class Telekom extends AddressConnector implements Connector
