package de.cweiske.jOnlineControl.frontend;

import de.cweiske.jOnlineControl.connectors.Connector;
import de.cweiske.jOnlineControl.Settings;
import de.cweiske.jOnlineControl.Frontend;
import de.cweiske.jOnlineControl.Status;
import de.cweiske.jOnlineControl.StatusControl;
import de.cweiske.jOnlineControl.frontend.helper.ActionMenu;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * SimpleWindow frontend for jOnlineControl
 *
 * Creates a window with a menu and an icon.
 * The menu provides actions like connect, disconnect and status
 * The icon displays the current connection status.
 *
 * @author Christian Weiske <cweiske@cweiske.de>
 */
public class SimpleWindow implements Updateable, ActionListener
{
    Connector connector;
    protected ActionMenu actionMenu;
    protected JButton btnImage;

    ImageIcon imgConnected;
    ImageIcon imgDisconnected;
    ImageIcon imgError;

    StatusControl sc;


    public SimpleWindow(Connector connector)
    {
        this.connector = connector;
        this.buildGui();
        sc = new StatusControl(this);
        sc.startTimer();
    }



    protected void buildGui()
    {
        this.imgConnected       = new ImageIcon( Frontend.class.getResource( "icons/connect_established.png"));
        this.imgDisconnected    = new ImageIcon( Frontend.class.getResource( "icons/connect_no.png"));
        this.imgError           = new ImageIcon( Frontend.class.getResource( "icons/button_cancel.png"));

        JFrame frame = new JFrame(Frontend.resbundle.getString("program.title"));
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        JMenuBar menuBar = new JMenuBar();

        //Build the first menu.
        JMenu menu = new JMenu(Frontend.resbundle.getString("menu.title"));
        this.actionMenu = new ActionMenu(this);
        this.actionMenu.populateMenu(menu);
        menuBar.add(menu);
        frame.setJMenuBar(menuBar);


        Container cp = frame.getContentPane();
        cp.setLayout( new BorderLayout());
        cp.setBackground(Color.white);
        this.btnImage = new JButton(this.imgError);
        this.btnImage.setBackground(Color.white);
        this.btnImage.addActionListener(this);
        this.btnImage.setFocusPainted(false);
        cp.add(this.btnImage);

        //Display the window.
        frame.setSize(100, 100);
        frame.setVisible(true);
    }//protected void buildGui()



    public void updateStatus(Status status)
    {
        ImageIcon img;
        if (status == null) {
            img = this.imgError;
        } else {
            if (status.isConnected()) {
                img = this.imgConnected;
            } else {
                img = this.imgDisconnected;
            }
        }
        this.btnImage.setIcon(img);
        this.actionMenu.updateStatus(status);
    }



    public void reloadSettings()
    {
        this.connector.setAddress(Settings.singleton().getIp());
    }



    public void connect()
    {
        this.connector.connect();
    }



    public void disconnect()
    {
        this.connector.disconnect();
    }



    public Connector getConnector()
    {
        return this.connector;
    }



    public void setConnector(Connector connector)
    {
        this.connector = connector;
        this.sc.resetStatus();
    }



    public void actionPerformed(ActionEvent actionEvent)
    {
        this.actionMenu.switchStatusFrame();
    }
}//public class SimpleWindow implements Updateable
