package de.cweiske.jOnlineControl.frontend;

import de.cweiske.jOnlineControl.connectors.Connector;
import de.cweiske.jOnlineControl.Frontend;
import de.cweiske.jOnlineControl.Status;
import de.cweiske.jOnlineControl.StatusControl;
import de.cweiske.jOnlineControl.Settings;
import de.cweiske.jOnlineControl.frontend.helper.ActionMenu;
import org.jdesktop.jdic.tray.*;

import javax.swing.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * Tray icon frontend
 */
public class TrayIcon implements Updateable, ActionListener
{
    org.jdesktop.jdic.tray.TrayIcon ti;
    ImageIcon imgConnected;
    ImageIcon imgDisconnected;
    ImageIcon imgError;

    StatusControl sc;

    JPopupMenu popupMenu;

    /**
     * The driver to use
     */
    protected Connector connector;
    protected ActionMenu actionMenu;

    String strConnected;
    String strDisconnected;



    public TrayIcon(Connector connector)
    {
        this.connector = connector;
        this.buildGui();
        sc = new StatusControl(this);
        sc.startTimer();
    }//public TrayIcon(Connector connector)



    protected void buildGui()
    {
        this.strConnected		= Frontend.resbundle.getString("status.connected");
        this.strDisconnected	= Frontend.resbundle.getString("status.disconnected");

        this.imgConnected       = new ImageIcon( Frontend.class.getResource( "icons/connect_established.png"));
        this.imgDisconnected    = new ImageIcon( Frontend.class.getResource( "icons/connect_no.png"));
        this.imgError           = new ImageIcon( Frontend.class.getResource( "icons/button_cancel.png"));

        SystemTray tray = SystemTray.getDefaultSystemTray();

        this.popupMenu = new JPopupMenu(Frontend.resbundle.getString("program.title"));
        this.actionMenu = new ActionMenu(this);
        this.actionMenu.populateMenu(this.popupMenu);

        ti = new org.jdesktop.jdic.tray.TrayIcon(
                this.imgDisconnected,
                Frontend.resbundle.getString("program.title"),
                this.popupMenu
        );
        ti.setIconAutoSize(true);
        ti.addActionListener(this);

        tray.addTrayIcon(ti);
    }//protected void buildGui()



    public void updateStatus(Status status)
    {
        if (status == null) {
            System.out.println(
                    Frontend.resbundle
                            .getString("error.checkip")
                            .replaceAll("%s", Status.ip2string(connector.getAddress()))
            );
            this.ti.setIcon( this.imgError);
            this.ti.setIconAutoSize( true);
        } else {
            if (status.isConnected()) {
                this.ti.setToolTip(this.strConnected);
                this.ti.setIcon( this.imgConnected);
            } else {
                this.ti.setToolTip( this.strDisconnected);
                this.ti.setIcon( this.imgDisconnected);
            }
        }
        this.ti.setIconAutoSize(true);

        this.actionMenu.updateStatus(status);
    }//public void updateStatus(Status status)



    public void reloadSettings()
    {
        this.connector.setAddress(Settings.singleton().getIp());
    }



    public void connect()
    {
        this.connector.connect();
    }



    public void disconnect()
    {
        this.connector.disconnect();
    }



    public Connector getConnector()
    {
        return this.connector;
    }



    public void actionPerformed(ActionEvent actionEvent)
    {
        this.actionMenu.switchStatusFrame();
    }

    

    public void setConnector(Connector connector)
    {
        this.connector = connector;
        this.sc.resetStatus();
    }

}//public class TrayIcon implements Updateable
