package de.cweiske.jOnlineControl.frontend.helper;

import de.cweiske.jOnlineControl.Frontend;
import de.cweiske.jOnlineControl.SettingsDialog;
import de.cweiske.jOnlineControl.StatusFrame;
import de.cweiske.jOnlineControl.Status;
import de.cweiske.jOnlineControl.frontend.Updateable;

import javax.swing.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 *
 *
 */
public class ActionMenu implements ActionListener
{
    JMenuItem mnuiSettings;
    JMenuItem mnuiStatus;

    JMenuItem mnuiConnect;
    JMenuItem mnuiDisconnect;

    JMenuItem mnuiAbout;
    JMenuItem mnuiExit;

    protected Updateable updateable;
    protected StatusFrame frmStatus;



    public ActionMenu(Updateable updateable)
    {
        this.updateable = updateable;
    }



    public void populateMenu(JComponent component)
    {
        this.mnuiSettings	= new JMenuItem(Frontend.resbundle.getString("menu.settings"));
        this.mnuiStatus		= new JMenuItem(Frontend.resbundle.getString("menu.status"));
        this.mnuiConnect	= new JMenuItem(Frontend.resbundle.getString("menu.connect"));
        this.mnuiDisconnect	= new JMenuItem(Frontend.resbundle.getString("menu.disconnect"));
        this.mnuiAbout		= new JMenuItem(Frontend.resbundle.getString("menu.about"));
        this.mnuiExit		= new JMenuItem(Frontend.resbundle.getString("menu.quit"));

        this.mnuiSettings	.addActionListener( this);
        this.mnuiStatus		.addActionListener( this);
        this.mnuiConnect	.addActionListener( this);
        this.mnuiDisconnect	.addActionListener( this);
        this.mnuiAbout		.addActionListener( this);
        this.mnuiExit		.addActionListener( this);

        //initial state is connected, so disable this here
        this.mnuiDisconnect.setEnabled( false);

        component.add(this.mnuiStatus);
        component.add(this.mnuiSettings);
            addSeparator(component);
        component.add(this.mnuiConnect);
        component.add(this.mnuiDisconnect);
            addSeparator(component);
        component.add(this.mnuiAbout);
        component.add(this.mnuiExit);

    }//public void populateMenu(JComponent component)



    protected static void addSeparator(JComponent component)
    {
        if (component instanceof JPopupMenu) {
            ((JPopupMenu)component).addSeparator();
        } else if (component instanceof JMenu) {
            ((JMenu)component).addSeparator();
        }
    }//protected static void addSeparator(JComponent component)



    public void actionPerformed(ActionEvent event)
    {
        if (event.getSource() == this.mnuiExit) {
            System.exit( 0);

        } else if (event.getSource() == this.mnuiStatus) {
            this.showStatusFrame();

        } else if (event.getSource() == this.mnuiConnect) {
            if (this.updateable != null) {
                this.updateable.connect();
            }

        } else if (event.getSource() == this.mnuiDisconnect) {
            if (this.updateable != null) {
                this.updateable.disconnect();
            }

        } else if (event.getSource() == this.mnuiAbout) {
            JOptionPane.showMessageDialog(
                    null,
                    Frontend.resbundle.getString("about.text")
                            .replaceAll("\\{0\\}", Frontend.version)
                            .replaceAll("\\{1\\}", Frontend.versionName),
                    Frontend.resbundle.getString("about.title"),
                    JOptionPane.INFORMATION_MESSAGE
            );

        } else if (event.getSource() == this.mnuiSettings) {
            new SettingsDialog(this.updateable);
        }

    }//public void actionPerformed(ActionEvent event)



    /**
     * displays the status dialog
     */
    public void showStatusFrame()
    {
        if (this.frmStatus == null) {
            this.frmStatus  = new StatusFrame(this.updateable, false);
        }
        this.frmStatus.display();
    }//public void showStatusFrame()



    /**
     * switches the visibility of the status dialog
     */
    public void switchStatusFrame()
    {
        if (this.frmStatus == null || !this.frmStatus.isVisible()) {
            this.showStatusFrame();
        } else {
            this.frmStatus.setVisible(false);
            this.frmStatus.updateStatus();
        }
    }//public void switchStatusFrame()



    public void updateStatus(Status status)
    {
        if (status == null) {
            this.mnuiConnect.setEnabled(false);
            this.mnuiDisconnect.setEnabled(false);
        } else {
            boolean isConnected = status.isConnected();
            this.mnuiConnect    .setEnabled(!isConnected);
            this.mnuiDisconnect .setEnabled(isConnected);
        }

        if (this.frmStatus != null && this.frmStatus.isVisible()) {
            this.frmStatus.updateStatus();
        }
    }//public void updateStatus(Status status)

}//public class ActionMenu implements ActionListener